@@ -8,8 +8,7 @@ from typing import Any, Dict, List, Optional, cast
 
 from yaml import safe_load
 
-from suite_py.lib import logger
-from suite_py.lib import metrics
+from suite_py.lib import logger, metrics
 from suite_py.lib.handler.changelog_handler import ChangelogHandler
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.github_handler import GithubHandler
