@@ -3,17 +3,21 @@ from inspect import signature
 
 from suite_py.lib.config import Config
 from suite_py.lib.handler.captainhook_handler import CaptainHook
+from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.okta_handler import Okta
+from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 from suite_py.lib.tokens import Tokens
 
 
 @dataclasses.dataclass
 class Context:
-    project: str
-    config: Config
     captainhook: CaptainHook
-    tokens: Tokens
+    config: Config
+    git_handler: GitHandler
     okta: Okta
+    project: str
+    tokens: Tokens
+    youtrack_handler: YoutrackHandler
 
     # Call the function to_call with kwargs, injecting fields from self as default arguments
     def call(self, to_call, **kwargs):
