@@ -11,25 +11,37 @@ from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 
 
 class CreateBranch:
-    def __init__(self, project, card, config, tokens, autostash=False):
-        self._project = project
-        self._card = card
+    def __init__(
+        self,
+        config,
+        git_handler: GitHandler,
+        youtrack_handler: YoutrackHandler,
+    ):
         self._config = config
-        self._youtrack = YoutrackHandler(config, tokens)
-        self._git = GitHandler(project, config)
-        self._autostash = autostash
+        self._git_handler = git_handler
+        self._youtrack = youtrack_handler
 
     @metrics.command("create-branch")
-    def run(self):
-        if not self._git.is_detached() and self._git.is_dirty() and not self._autostash:
+    def run(
+        self,
+        autostash=False,
+        branch_name=None,
+        card_id=None,
+        parent_branch=None,
+    ):
+        if (
+            not self._git_handler.is_detached()
+            and self._git_handler.is_dirty()
+            and not autostash
+        ):
             # Default behaviour is to pull when not detached.
             # Can't do that with uncommitted changes.
             logger.error("You have some uncommitted changes, I can't continue")
             sys.exit(-1)
 
         try:
-            if self._card:
-                issue = self._youtrack.get_issue(self._card)
+            if card_id:
+                issue = self._youtrack.get_issue(card_id)
             else:
                 issue = self._youtrack.get_issue(self._ask_card())
         except Exception:
@@ -38,7 +50,7 @@ class CreateBranch:
             )
             sys.exit(-1)
 
-        self._checkout_branch(issue, self._autostash)
+        self._checkout_branch(issue, autostash, parent_branch, branch_name)
 
         user = self._youtrack.get_current_user()
         self._youtrack.assign_to(issue["id"], user["login"])
@@ -95,33 +107,45 @@ class CreateBranch:
             )
             return []
 
-    def _checkout_branch(self, issue, autostash=False):
+    def _checkout_branch(
+        self, issue, autostash=False, parent_branch=None, branch_name_template=None
+    ):
         default_parent_branch_name = self._config.user.get(
-            "default_parent_branch", self._git.current_branch_name()
+            "default_parent_branch", self._git_handler.current_branch_name()
         )
 
-        parent_branch_name = prompt_utils.ask_questions_input(
-            "Insert initial branch: ", default_parent_branch_name
+        parent_branch_name = parent_branch or prompt_utils.ask_questions_input(
+            "Enter parent branch: ", default_parent_branch_name
         )
 
         full_branch_name = ""
         branch_name = _normalize_git_ref_segment(issue["summary"])
         branch_type = _normalize_git_ref_segment(issue["Type"])
 
-        while True:
-            branch_name = str(
-                prompt_utils.ask_questions_input("Enter branch name: ", branch_name)
+        if branch_name_template:
+            # Use the template and replace placeholders
+            full_branch_name = branch_name_template.format(
+                card_id=issue["idReadable"], type=branch_type, summary=branch_name
             )
 
-            full_branch_name = f"{issue['idReadable']}/{branch_type}/{branch_name}"
-            if is_branch_name_valid(full_branch_name):
-                break
+            if not is_branch_name_valid(full_branch_name):
+                logger.error(f"Invalid branch name from template: {full_branch_name}")
+                sys.exit(-1)
+        else:
+            while True:
+                branch_name = str(
+                    prompt_utils.ask_questions_input("Enter branch name: ", branch_name)
+                )
 
-            logger.error(f"Invalid branch name: {full_branch_name}. Try again?")
+                full_branch_name = f"{issue['idReadable']}/{branch_type}/{branch_name}"
+                if is_branch_name_valid(full_branch_name):
+                    break
 
-        self._git.checkout(parent_branch_name, autostash=autostash)
+                logger.error(f"Invalid branch name: {full_branch_name}. Try again?")
 
-        self._git.checkout(full_branch_name, new=True, autostash=autostash)
+        self._git_handler.checkout(parent_branch_name, autostash=autostash)
+
+        self._git_handler.checkout(full_branch_name, new=True, autostash=autostash)
 
 
 # Normalize a string into a valid segment(ie. the part of the branch name between the /)
