@@ -7,7 +7,6 @@ from suite_py.lib import logger, metrics
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.captainhook_handler import CaptainHook
-from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.github_handler import GithubHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
@@ -22,7 +21,6 @@ class MergePR:
         self._captainhook = captainhook
         self._git = GitHandler(project, config)
         self._github = GithubHandler(tokens)
-        self._drone = DroneHandler(config, tokens, repo=project)
 
     @metrics.command("merge-pr")
     def run(self):
@@ -56,13 +54,6 @@ class MergePR:
 
         logger.info("Pull request merged on master!")
 
-        if self._drone.parse_yaml():
-            drone_build_number = self._drone.get_pr_build_number(merge_status.sha)
-            drone_build_url = self._drone.get_build_url(drone_build_number)
-
-            if drone_build_url:
-                logger.info(f"You can follow the build status at {drone_build_url}")
-
         self._git.fetch()
         if self._git.remote_branch_exists(branch_name):
             self._git.delete_remote_branch(branch_name)
@@ -84,9 +75,7 @@ class MergePR:
             logger.warning(
                 "There is no YouTrack issue in the branch name or the selected issue does not exist."
             )
-            logger.warning(
-                "No card updated on YouTrack and no QA turned off automatically"
-            )
+            logger.warning("No card updated on YouTrack")
 
         logger.info("All done!")
         sys.exit()
