@@ -17,7 +17,15 @@ def setup(verbose):
         level=level,
         format=LOG_FORMAT,
         datefmt="[%X]",
-        handlers=[RichHandler(rich_tracebacks=True, markup=False)],
+        handlers=[
+            RichHandler(
+                rich_tracebacks=True,
+                markup=False,
+                show_path=False,
+                show_level=False,
+                show_time=False,
+            )
+        ],
     )
 
     logger = logging.getLogger(LOGGER_NAME)
